Exception: OpenLoam::NotAuthorizedError
- Defined in:
- lib/open_loam/errors.rb
Overview
Raised by admin controllers / callers when a policy check fails, and by a OpenLoam::Workflow transition the current actor's role may not perform.
Raised by admin controllers / callers when a policy check fails, and by a OpenLoam::Workflow transition the current actor's role may not perform.