Class: OpenLoam::Sso::UnverifiedDomainError

Inherits:
Error
  • Object
show all
Defined in:
lib/open_loam/sso.rb

Overview

The provider has not proven it owns its domain, so it may not adopt an existing account. Ownership is stamped out of band by an operator (rake open_loam:sso:verify_domain).